@@ -186,7 +186,7 @@
 
 (define (get-hint)
   (or (check-to-foundation 0)
-      (list 0 (gettext "Try rearranging the cards"))))
+      (list 0 (_"Try rearranging the cards"))))
 
 (define (get-options) 
   #f)
