@@ -46,18 +46,18 @@
 #include <iostream>
 using namespace std;
 
-BJGameRules      *rules;
-LoadablePlayer   *strategy;
-Hand             *dealer;
-Probabilities    *dealerProbabilities;
-Shoe             *shoe;
-BJShoe           *distribution;
-PlayerHand       *player;
+BJGameRules      *rules = NULL;
+LoadablePlayer   *strategy = NULL;
+Hand             *dealer = NULL;
+Probabilities    *dealerProbabilities = NULL;
+Shoe             *shoe = NULL;
+BJShoe           *distribution = NULL;
+PlayerHand       *player = NULL;
 
 GList            *playerHands = NULL;
 gfloat           lastWager = 5.0;
 Card             tempCard;
-PlayerHand       *tempHand;
+PlayerHand       *tempHand = NULL;
 
 gint             numDecks;
 gint             dealerSpeed;
@@ -302,6 +302,34 @@ bj_game_find_and_read_rules (gchar *filename)
   return ruleset;
 }
 
+static gchar *
+bj_game_get_config_dir (void)
+{
+  gchar *conf_dir = NULL;
+
+  conf_dir = g_build_filename (gnome_user_dir_get (),
+                               "blackjack.d",
+                               NULL);
+  return conf_dir;
+}
+
+static void
+bj_game_ensure_config_dir_exists (const char *dir)
+{
+  if (g_file_test (dir, G_FILE_TEST_IS_DIR) == FALSE)
+    {
+      if (g_file_test (dir, G_FILE_TEST_EXISTS) == TRUE)
+        {
+          // FIXME: use a dialog
+          cerr << dir << " exists, please move it out of the way." << endl;
+        }
+      if (mkdir (dir, 488) != 0)
+        {
+          cerr << "Failed to create directory " << dir << endl;
+        }
+    }
+}
+
 static void
 bj_game_eval_installed_file (gchar *file)
 {
@@ -322,7 +350,8 @@ bj_game_eval_installed_file (gchar *file)
   if (g_file_test (installed_filename, G_FILE_TEST_EXISTS))
     {
       rules = bj_game_read_rules (installed_filename);
-      
+      g_free (installed_filename);
+
       // set globals
       numDecks = rules->getNumDecks ();
       dealerSpeed = rules->getDealerSpeed ();
@@ -330,21 +359,17 @@ bj_game_eval_installed_file (gchar *file)
       BJStrategy maxValueStrategy;
       Progress progress;
 
-      gchar *cache_filename = g_strdup_printf ("%s%s", relative, ".dat");
+      gchar *cache_filename = g_strdup_printf ("%s%s", file, ".dat");
+
+      char *config_dir = bj_game_get_config_dir ();
+      bj_game_ensure_config_dir_exists (config_dir);
+      installed_filename = g_build_filename (config_dir, cache_filename, NULL);
+      g_free (config_dir);
 
-      installed_filename = gnome_program_locate_file 
-        (NULL, 
-         GNOME_FILE_DOMAIN_APP_DATADIR,
-         cache_filename,
-         FALSE, NULL);
       gboolean use_cache = false;
       if (g_file_test (installed_filename, G_FILE_TEST_EXISTS))
         use_cache = true;
 
-      // This is a quick and very, very, dirty fix for 2.4 to make
-      // sure that we work on all architectures (see bug #132486).
-      use_cache = false;
-
       if (! use_cache)
         splash_new ();
       strategy = new LoadablePlayer (numDecks, rules, 
@@ -352,13 +377,11 @@ bj_game_eval_installed_file (gchar *file)
                                      progress, 
                                      (use_cache) ? installed_filename : NULL);
 
-      /*
-        Use the following to save a cache file:
-        if (!use_cache)
-        strategy->save (cache_filename);
-      */
       if (! use_cache)
-        splash_destroy ();
+        {
+          strategy->saveXML (installed_filename);
+          splash_destroy ();
+        }
 
       g_free (cache_filename);
      } 
@@ -373,7 +396,6 @@ bj_game_eval_installed_file (gchar *file)
                                              GTK_BUTTONS_CLOSE,
                                              "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
                                              message, message2);
-      gtk_dialog_set_has_separator (GTK_DIALOG (w), FALSE);
       gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (w)->label), TRUE);
       gtk_dialog_run (GTK_DIALOG (w));
       gtk_widget_destroy (w);
@@ -394,10 +416,6 @@ void bj_game_new (gchar* file, guint *seedp )
 
   if (file && strcmp (file, game_file))
     {
-      gchar buf[100];
-      GtkWidget *ms;
-      gint pos;
-
       game_file = file;
 
       bj_game_eval_installed_file (file);
@@ -427,10 +445,18 @@ void bj_game_new (gchar* file, guint *seedp )
 
   // Prepare to play blackjack.
 
+  if (dealer)
+    delete dealer;
   dealer = new Hand;
   dealer->hslot = NULL;
+  if (dealerProbabilities)
+    delete dealerProbabilities;
   dealerProbabilities = new Probabilities (rules->getHitSoft17 ());
+  if (shoe)
+    delete shoe;
   shoe = new Shoe (numDecks);
+  if (distribution)
+    delete distribution;
   distribution = new BJShoe (numDecks);
 
   bj_clear_table ();
